@@ -2,7 +2,7 @@
 #'
 #' @description Calculate a selected group of metrics
 #'
-#' @param landscape Raster* Layer, Stack, Brick, SpatRaster (terra), stars, or a list of rasterLayers.
+#' @param landscape A categorical raster object: SpatRaster; Raster* Layer, Stack, Brick; stars or a list of SpatRasters.
 #' @param level Level of metrics. Either 'patch', 'class' or 'landscape' (or vector with combination).
 #' @param metric Abbreviation of metrics (e.g. 'area').
 #' @param name Full name of metrics (e.g. 'core area').
@@ -45,19 +45,20 @@
 #'
 #' @examples
 #' \dontrun{
+#' landscape <- terra::rast(landscapemetrics::landscape)
 #' calculate_lsm(landscape, progress = TRUE)
 #' calculate_lsm(landscape, what = c("patch", "lsm_c_te", "lsm_l_pr"))
-#' calculate_lsm(landscape, level = c("class", "landscape"), type = "aggregation metric")
+#' calculate_lsm(landscape, level = c("class", "landscape"),
+#' type = "aggregation metric")
 #' }
 #'
 #' @aliases calculate_lsm
 #' @rdname calculate_lsm
 #'
 #' @references
-#' McGarigal, K., SA Cushman, and E Ene. 2012. FRAGSTATS v4: Spatial Pattern Analysis
-#' Program for Categorical and Continuous Maps. Computer software program produced by
-#' the authors at the University of Massachusetts, Amherst. Available at the following
-#' web site: https://www.umass.edu/landeco/
+#' McGarigal K., SA Cushman, and E Ene. 2023. FRAGSTATS v4: Spatial Pattern Analysis
+#' Program for Categorical Maps. Computer software program produced by the authors;
+#' available at the following web site: https://www.fragstats.org
 #'
 #' @export
 calculate_lsm <- function(landscape,
@@ -165,10 +166,10 @@ calculate_lsm_internal <- function(landscape,
     points <- raster_to_points(landscape)[, 2:4]
 
     # resolution of original raster
-    resolution <- raster::res(landscape)
+    resolution <- terra::res(landscape)
 
     # convert to matrix
-    landscape <- raster::as.matrix(landscape)
+    landscape <- terra::as.matrix(landscape, wide = TRUE)
 
     result <- do.call(rbind, lapply(seq_along(metrics_calc), FUN = function(current_metric) {
 
@@ -198,7 +199,7 @@ calculate_lsm_internal <- function(landscape,
                           "name", "type", "function_name")
 
         result <- merge(x = result,
-                        y = landscapemetrics::lsm_abbreviations_names,
+                        y = lsm_abbreviations_names,
                         by = c("level", "metric"),
                         all.x = TRUE, sort = FALSE, suffixes = c("", ""))
 
