@@ -2,7 +2,7 @@
 #'
 #' @description Coefficient of variation of Contiguity index (Shape metric)
 #'
-#' @param landscape Raster* Layer, Stack, Brick, SpatRaster (terra), stars, or a list of rasterLayers.
+#' @param landscape A categorical raster object: SpatRaster; Raster* Layer, Stack, Brick; stars or a list of SpatRasters.
 #' @param directions The number of directions in which patches should be connected: 4 (rook's case) or 8 (queen's case).
 #'
 #' @details
@@ -41,16 +41,16 @@
 #' @return tibble
 #'
 #' @examples
+#' landscape <- terra::rast(landscapemetrics::landscape)
 #' lsm_c_contig_cv(landscape)
 #'
 #' @aliases lsm_c_contig_cv
 #' @rdname lsm_c_contig_cv
 #'
 #' @references
-#' McGarigal, K., SA Cushman, and E Ene. 2012. FRAGSTATS v4: Spatial Pattern Analysis
-#' Program for Categorical and Continuous Maps. Computer software program produced by
-#' the authors at the University of Massachusetts, Amherst. Available at the following
-#' web site: https://www.umass.edu/landeco/
+#' McGarigal K., SA Cushman, and E Ene. 2023. FRAGSTATS v4: Spatial Pattern Analysis
+#' Program for Categorical Maps. Computer software program produced by the authors;
+#' available at the following web site: https://www.fragstats.org
 #'
 #' LaGro, J. 1991. Assessing patch shape in landscape mosaics.
 #' Photogrammetric Engineering and Remote Sensing, 57(3), 285-293
@@ -85,7 +85,7 @@ lsm_c_contig_cv_calc <- function(landscape, directions) {
     }
 
     contig_cv <- stats::aggregate(x = contig[, 5], by = contig[, 2],
-                                  FUN = raster::cv)
+                                  FUN = function(x) stats::sd(x) / mean(x) * 100)
 
     return(tibble::tibble(level = "class",
                           class = as.integer(contig_cv$class),
