@@ -2,7 +2,7 @@
 #'
 #' @description Coefficient of variation of core area (Core area metric)
 #' @param directions The number of directions in which patches should be connected: 4 (rook's case) or 8 (queen's case).
-#' @param landscape Raster* Layer, Stack, Brick, SpatRaster (terra), stars, or a list of rasterLayers.
+#' @param landscape A categorical raster object: SpatRaster; Raster* Layer, Stack, Brick; stars or a list of SpatRasters.
 #' @param consider_boundary Logical if cells that only neighbour the landscape
 #' boundary should be considered as core
 #' @param edge_depth Distance (in cells) a cell has the be away from the patch
@@ -24,8 +24,7 @@
 #' Increases, without limit, as the variation of patch core areas increases.}
 #'
 #' @seealso
-#' \code{\link{lsm_p_core}},
-#' \code{\link{cv}}, \cr
+#' \code{\link{lsm_p_core}}, \cr
 #' \code{\link{lsm_c_core_mn}},
 #' \code{\link{lsm_c_core_sd}}, \cr
 #' \code{\link{lsm_l_core_mn}},
@@ -35,16 +34,16 @@
 #' @return tibble
 #'
 #' @examples
+#' landscape <- terra::rast(landscapemetrics::landscape)
 #' lsm_c_core_cv(landscape)
 #'
 #' @aliases lsm_c_core_cv
 #' @rdname lsm_c_core_cv
 #'
 #' @references
-#' McGarigal, K., SA Cushman, and E Ene. 2012. FRAGSTATS v4: Spatial Pattern Analysis
-#' Program for Categorical and Continuous Maps. Computer software program produced by
-#' the authors at the University of Massachusetts, Amherst. Available at the following
-#' web site: https://www.umass.edu/landeco/
+#' McGarigal K., SA Cushman, and E Ene. 2023. FRAGSTATS v4: Spatial Pattern Analysis
+#' Program for Categorical Maps. Computer software program produced by the authors;
+#' available at the following web site: https://www.fragstats.org
 #'
 #' @export
 lsm_c_core_cv <- function(landscape, directions = 8, consider_boundary = FALSE, edge_depth = 1) {
@@ -84,7 +83,7 @@ lsm_c_core_cv_calc <- function(landscape, directions, consider_boundary, edge_de
 
     # summarise for class
     core_cv <- stats::aggregate(x = core[, 5], by = core[, 2],
-                                FUN = raster::cv)
+                                FUN = function(x) stats::sd(x) / mean(x) * 100)
 
     return(tibble::tibble(level = "class",
                           class = as.integer(core_cv$class),
