@@ -2,7 +2,7 @@
 #'
 #' @description Coefficient of variation radius of gyration (Area and edge metric)
 #'
-#' @param landscape Raster* Layer, Stack, Brick, SpatRaster (terra), stars, or a list of rasterLayers.
+#' @param landscape A categorical raster object: SpatRaster; Raster* Layer, Stack, Brick; stars or a list of SpatRasters.
 #' @param directions The number of directions in which patches should be
 #' connected: 4 (rook's case) or 8 (queen's case).
 #' @param cell_center If true, the coordinates of the centroid are forced to be
@@ -30,8 +30,7 @@
 #' increases.}
 #'
 #' @seealso
-#' \code{\link{lsm_p_gyrate}},
-#' \code{\link{cv}}, \cr
+#' \code{\link{lsm_p_gyrate}}, \cr
 #' \code{\link{lsm_c_gyrate_mn}},
 #' \code{\link{lsm_c_gyrate_sd}}, \cr
 #' \code{\link{lsm_l_gyrate_mn}},
@@ -41,16 +40,16 @@
 #' @return tibble
 #'
 #' @examples
+#' landscape <- terra::rast(landscapemetrics::landscape)
 #' lsm_c_gyrate_cv(landscape)
 #'
 #' @aliases lsm_c_gyrate_cv
 #' @rdname lsm_c_gyrate_cv
 #'
 #' @references
-#' McGarigal, K., SA Cushman, and E Ene. 2012. FRAGSTATS v4: Spatial Pattern Analysis
-#' Program for Categorical and Continuous Maps. Computer software program produced by
-#' the authors at the University of Massachusetts, Amherst. Available at the following
-#' web site: https://www.umass.edu/landeco/
+#' McGarigal K., SA Cushman, and E Ene. 2023. FRAGSTATS v4: Spatial Pattern Analysis
+#' Program for Categorical Maps. Computer software program produced by the authors;
+#' available at the following web site: https://www.fragstats.org
 #'
 #' Keitt, T. H., Urban, D. L., & Milne, B. T. 1997. Detecting critical scales
 #' in fragmented landscapes. Conservation ecology, 1(1).
@@ -91,7 +90,7 @@ lsm_c_gyrate_cv_calc <- function(landscape, directions, cell_center,
     }
 
     gyrate_cv <- stats::aggregate(x = gyrate[, 5], by = gyrate[, 2],
-                                  FUN = raster::cv)
+                                  FUN = function(x) stats::sd(x) / mean(x) * 100)
 
     return(tibble::tibble(level = "class",
                           class = as.integer(gyrate_cv$class),
