@@ -2,7 +2,7 @@
 #
 #' @description Interspersion and Juxtaposition index (Aggregation metric)
 #
-#' @param landscape Raster* Layer, Stack, Brick, SpatRaster (terra), stars, or a list of rasterLayers.
+#' @param landscape A categorical raster object: SpatRaster; Raster* Layer, Stack, Brick; stars or a list of SpatRasters.
 #' @param verbose Print warning message if not sufficient patches are present
 #
 #' @details
@@ -26,16 +26,16 @@
 #' @return tibble
 #
 #' @examples
-#'lsm_c_iji(landscape)
+#' landscape <- terra::rast(landscapemetrics::landscape)
+#' lsm_c_iji(landscape)
 #
 #' @aliases lsm_c_iji
 #' @rdname lsm_c_iji
 #
 #' @references
-#'McGarigal, K., SA Cushman, and E Ene. 2012. FRAGSTATS v4: Spatial Pattern Analysis
-#'Program for Categorical and Continuous Maps. Computer software program produced by
-#'the authors at the University of Massachusetts, Amherst. Available at the following
-#'web site: https://www.umass.edu/landeco/
+#' McGarigal K., SA Cushman, and E Ene. 2023. FRAGSTATS v4: Spatial Pattern Analysis
+#' Program for Categorical Maps. Computer software program produced by the authors;
+#' available at the following web site: https://www.fragstats.org
 #'
 #'McGarigal, K., & Marks, B. J. 1995. FRAGSTATS: spatial pattern analysis
 #'program for quantifying landscape structure. Gen. Tech. Rep. PNW-GTR-351.
@@ -62,7 +62,7 @@ lsm_c_iji_calc <- function(landscape, verbose) {
 
     # conver to matrix
     if (!inherits(x = landscape, what = "matrix")) {
-        landscape <- raster::as.matrix(landscape)
+        landscape <- terra::as.matrix(landscape, wide = TRUE)
     }
 
     # all cells are NA
