@@ -2,7 +2,7 @@
 #'
 #' @description Coefficient of variation of patch area (Area and edge metric)
 #'
-#' @param landscape Raster* Layer, Stack, Brick, SpatRaster (terra), stars, or a list of rasterLayers
+#' @param landscape A categorical raster object: SpatRaster; Raster* Layer, Stack, Brick; stars or a list of SpatRasters
 #' @param directions The number of directions in which patches should be connected: 4 (rook's case) or 8 (queen's case).
 #'
 #' @details
@@ -20,8 +20,7 @@
 #' Increases, without limit, as the variation of patch areas increases.}
 #'
 #' @seealso
-#' \code{\link{lsm_p_area}},
-#' \code{\link{cv}}, \cr
+#' \code{\link{lsm_p_area}}, \cr
 #' \code{\link{lsm_c_area_mn}},
 #' \code{\link{lsm_c_area_sd}},
 #' \code{\link{lsm_c_area_cv}}, \cr
@@ -31,16 +30,16 @@
 #' @return tibble
 #'
 #' @examples
+#' landscape <- terra::rast(landscapemetrics::landscape)
 #' lsm_l_area_cv(landscape)
 #'
 #' @aliases lsm_l_area_cv
 #' @rdname lsm_l_area_cv
 #'
 #' @references
-#' McGarigal, K., SA Cushman, and E Ene. 2012. FRAGSTATS v4: Spatial Pattern Analysis
-#' Program for Categorical and Continuous Maps. Computer software program produced by
-#' the authors at the University of Massachusetts, Amherst. Available at the following
-#' web site: https://www.umass.edu/landeco/
+#' McGarigal K., SA Cushman, and E Ene. 2023. FRAGSTATS v4: Spatial Pattern Analysis
+#' Program for Categorical Maps. Computer software program produced by the authors;
+#' available at the following web site: https://www.fragstats.org
 #'
 #' @export
 lsm_l_area_cv <- function(landscape, directions = 8) {
@@ -75,7 +74,7 @@ lsm_l_area_cv_calc <- function(landscape, directions, resolution = NULL){
     }
 
     # calculate cv
-    area_cv <- raster::cv(area_patch$value)
+    area_cv <- stats::sd(area_patch$value) / mean(area_patch$value) * 100
 
     return(tibble::tibble(level = "landscape",
                           class = as.integer(NA),
