@@ -2,7 +2,7 @@
 #'
 #' @description Coefficient of variation of core area index (Core area metric)
 #'
-#' @param landscape Raster* Layer, Stack, Brick, SpatRaster (terra), stars, or a list of rasterLayers.
+#' @param landscape A categorical raster object: SpatRaster; Raster* Layer, Stack, Brick; stars or a list of SpatRasters.
 #' @param directions The number of directions in which patches should be
 #' connected: 4 (rook's case) or 8 (queen's case).
 #' @param consider_boundary Logical if cells that only neighbour the landscape
@@ -29,8 +29,7 @@
 #' indices increases.}
 #'
 #' @seealso
-#' \code{\link{lsm_p_cai}},
-#' \code{\link{cv}}, \cr
+#' \code{\link{lsm_p_cai}}, \cr
 #' \code{\link{lsm_c_cai_mn}},
 #' \code{\link{lsm_c_cai_sd}},
 #' \code{\link{lsm_c_cai_cv}}, \cr
@@ -40,16 +39,16 @@
 #' @return tibble
 #'
 #' @examples
+#' landscape <- terra::rast(landscapemetrics::landscape)
 #' lsm_l_cai_cv(landscape)
 #'
 #' @aliases lsm_l_cai_cv
 #' @rdname lsm_l_cai_cv
 #'
 #' @references
-#' McGarigal, K., SA Cushman, and E Ene. 2012. FRAGSTATS v4: Spatial Pattern Analysis
-#' Program for Categorical and Continuous Maps. Computer software program produced by
-#' the authors at the University of Massachusetts, Amherst. Available at the following
-#' web site: https://www.umass.edu/landeco/
+#' McGarigal K., SA Cushman, and E Ene. 2023. FRAGSTATS v4: Spatial Pattern Analysis
+#' Program for Categorical Maps. Computer software program produced by the authors;
+#' available at the following web site: https://www.fragstats.org
 #'
 #' @export
 lsm_l_cai_cv <- function(landscape,
@@ -89,7 +88,7 @@ lsm_l_cai_cv_calc <- function(landscape, directions, consider_boundary, edge_dep
                               value = as.double(NA)))
     }
 
-    cai_cv <- raster::cv(cai_patch$value)
+    cai_cv <- stats::sd(cai_patch$value) / mean(cai_patch$value) * 100
 
     return(tibble::tibble(level = "landscape",
                           class = as.integer(NA),
