@@ -2,7 +2,7 @@
 #'
 #' @description Coefficient of variation of related circumscribing circle (Shape metric)
 #'
-#' @param landscape Raster* Layer, Stack, Brick, SpatRaster (terra), stars, or a list of rasterLayers.
+#' @param landscape A categorical raster object: SpatRaster; Raster* Layer, Stack, Brick; stars or a list of SpatRasters.
 #' @param directions The number of directions in which patches should be connected: 4 (rook's case) or 8 (queen's case).
 #'
 #' @details
@@ -33,16 +33,16 @@
 #' @return tibble
 #'
 #' @examples
+#' landscape <- terra::rast(landscapemetrics::landscape)
 #' lsm_l_circle_cv(landscape)
 #'
 #' @aliases lsm_l_circle_cv
 #' @rdname lsm_l_circle_cv
 #'
 #' @references
-#' McGarigal, K., SA Cushman, and E Ene. 2012. FRAGSTATS v4: Spatial Pattern Analysis
-#' Program for Categorical and Continuous Maps. Computer software program produced by
-#' the authors at the University of Massachusetts, Amherst. Available at the following
-#' web site: https://www.umass.edu/landeco/
+#' McGarigal K., SA Cushman, and E Ene. 2023. FRAGSTATS v4: Spatial Pattern Analysis
+#' Program for Categorical Maps. Computer software program produced by the authors;
+#' available at the following web site: https://www.fragstats.org
 #'
 #' Baker, W. L., and Y. Cai. 1992. The r.le programs for multiscale analysis of
 #' landscape structure using the GRASS geographical information system.
@@ -81,7 +81,7 @@ lsm_l_circle_cv_calc <- function(landscape, directions, resolution = NULL) {
                               value = as.double(NA)))
     }
 
-    circle_cv <- raster::cv(circle_patch$value)
+    circle_cv <- stats::sd(circle_patch$value) / mean(circle_patch$value) * 100
 
     return(tibble::tibble(level = "landscape",
                           class = as.integer(NA),
