@@ -2,7 +2,7 @@
 #'
 #' @description Coefficient of variation of core area (Core area metric)
 #'
-#' @param landscape Raster* Layer, Stack, Brick, SpatRaster (terra), stars, or a list of rasterLayers.
+#' @param landscape A categorical raster object: SpatRaster; Raster* Layer, Stack, Brick; stars or a list of SpatRasters.
 #' @param directions The number of directions in which patches should be
 #' connected: 4 (rook's case) or 8 (queen's case).
 #' @param consider_boundary Logical if cells that only neighbour the landscape
@@ -26,8 +26,7 @@
 #' Increases, without limit, as the variation of patch core areas increases.}
 #'
 #' @seealso
-#' \code{\link{lsm_p_core}},
-#' \code{\link{cv}}, \cr
+#' \code{\link{lsm_p_core}}, \cr
 #' \code{\link{lsm_c_core_mn}},
 #' \code{\link{lsm_c_core_sd}},
 #' \code{\link{lsm_c_core_cv}}, \cr
@@ -37,16 +36,16 @@
 #' @return tibble
 #'
 #' @examples
+#' landscape <- terra::rast(landscapemetrics::landscape)
 #' lsm_l_core_cv(landscape)
 #'
 #' @aliases lsm_l_core_cv
 #' @rdname lsm_l_core_cv
 #'
 #' @references
-#' McGarigal, K., SA Cushman, and E Ene. 2012. FRAGSTATS v4: Spatial Pattern Analysis
-#' Program for Categorical and Continuous Maps. Computer software program produced by
-#' the authors at the University of Massachusetts, Amherst. Available at the following
-#' web site: https://www.umass.edu/landeco/
+#' McGarigal K., SA Cushman, and E Ene. 2023. FRAGSTATS v4: Spatial Pattern Analysis
+#' Program for Categorical Maps. Computer software program produced by the authors;
+#' available at the following web site: https://www.fragstats.org
 #'
 #' @export
 lsm_l_core_cv <- function(landscape,
@@ -86,7 +85,7 @@ lsm_l_core_cv_calc <- function(landscape, directions, consider_boundary, edge_de
                               value = as.double(NA)))
     }
 
-    core_cv <- raster::cv(core_patch$value)
+    core_cv <- stats::sd(core_patch$value) / mean(core_patch$value) * 100
 
     return(tibble::tibble(level = "landscape",
                           class = as.integer(NA),
