@@ -2,7 +2,7 @@
 #'
 #' @description Coefficient of variation number of disjunct core areas (Core area metric)
 #'
-#' @param landscape Raster* Layer, Stack, Brick, SpatRaster (terra), stars, or a list of rasterLayers.
+#' @param landscape A categorical raster object: SpatRaster; Raster* Layer, Stack, Brick; stars or a list of SpatRasters.
 #' @param directions The number of directions in which patches should be
 #' connected: 4 (rook's case) or 8 (queen's case).
 #' @param consider_boundary Logical if cells that only neighbour the landscape
@@ -28,8 +28,7 @@
 #' increases.}
 #'
 #' @seealso
-#' \code{\link{lsm_p_ncore}},
-#' \code{\link{cv}}, \cr
+#' \code{\link{lsm_p_ncore}}, \cr
 #' \code{\link{lsm_c_dcore_mn}},
 #' \code{\link{lsm_c_dcore_sd}},
 #' \code{\link{lsm_c_dcore_cv}}, \cr
@@ -39,16 +38,16 @@
 #' @return tibble
 #'
 #' @examples
+#' landscape <- terra::rast(landscapemetrics::landscape)
 #' lsm_l_dcore_cv(landscape)
 #'
 #' @aliases lsm_l_dcore_cv
 #' @rdname lsm_l_dcore_cv
 #'
 #' @references
-#' McGarigal, K., SA Cushman, and E Ene. 2012. FRAGSTATS v4: Spatial Pattern Analysis
-#' Program for Categorical and Continuous Maps. Computer software program produced by
-#' the authors at the University of Massachusetts, Amherst. Available at the following
-#' web site: https://www.umass.edu/landeco/
+#' McGarigal K., SA Cushman, and E Ene. 2023. FRAGSTATS v4: Spatial Pattern Analysis
+#' Program for Categorical Maps. Computer software program produced by the authors;
+#' available at the following web site: https://www.fragstats.org
 #'
 #' @export
 lsm_l_dcore_cv <- function(landscape,
@@ -89,7 +88,7 @@ lsm_l_dcore_cv_calc <- function(landscape, directions, consider_boundary, edge_d
                               value = as.double(NA)))
     }
 
-    dcore_cv <- raster::cv(dcore_patch$value)
+    dcore_cv <- stats::sd(dcore_patch$value) / mean(dcore_patch$value) * 100
 
     return(tibble::tibble(level = "landscape",
                           class = as.integer(NA),
