@@ -2,7 +2,7 @@
 #'
 #' @description Coefficient of variation perimeter-area ratio (Shape metric)
 #'
-#' @param landscape Raster* Layer, Stack, Brick, SpatRaster (terra), stars, or a list of rasterLayers.
+#' @param landscape A categorical raster object: SpatRaster; Raster* Layer, Stack, Brick; stars or a list of SpatRasters.
 #' @param directions The number of directions in which patches should be
 #' connected: 4 (rook's case) or 8 (queen's case).
 #'
@@ -23,8 +23,7 @@
 #' increases.}
 #'
 #' @seealso
-#' \code{\link{lsm_p_para}},
-#' \code{\link{cv}}, \cr
+#' \code{\link{lsm_p_para}}, \cr
 #' \code{\link{lsm_c_para_mn}},
 #' \code{\link{lsm_c_para_sd}},
 #' \code{\link{lsm_c_para_cv}}, \cr
@@ -34,16 +33,16 @@
 #' @return tibble
 #'
 #' @examples
+#' landscape <- terra::rast(landscapemetrics::landscape)
 #' lsm_l_para_cv(landscape)
 #'
 #' @aliases lsm_l_para_cv
 #' @rdname lsm_l_para_cv
 #'
 #' @references
-#' McGarigal, K., SA Cushman, and E Ene. 2012. FRAGSTATS v4: Spatial Pattern Analysis
-#' Program for Categorical and Continuous Maps. Computer software program produced by
-#' the authors at the University of Massachusetts, Amherst. Available at the following
-#' web site: https://www.umass.edu/landeco/
+#' McGarigal K., SA Cushman, and E Ene. 2023. FRAGSTATS v4: Spatial Pattern Analysis
+#' Program for Categorical Maps. Computer software program produced by the authors;
+#' available at the following web site: https://www.fragstats.org
 #'
 #' @export
 lsm_l_para_cv <- function(landscape, directions = 8) {
@@ -76,7 +75,7 @@ lsm_l_para_cv_calc <- function(landscape, directions, resolution = NULL){
                               value = as.double(NA)))
     }
 
-    para_cv <- raster::cv(para_patch$value)
+    para_cv <- stats::sd(para_patch$value) / mean(para_patch$value) * 100
 
     return(tibble::tibble(level = "landscape",
                           class = as.integer(NA),
