@@ -2,7 +2,7 @@
 #'
 #' @description Mean perimeter-area ratio (Shape metric)
 #'
-#' @param landscape Raster* Layer, Stack, Brick, SpatRaster (terra), stars, or a list of rasterLayers.
+#' @param landscape A categorical raster object: SpatRaster; Raster* Layer, Stack, Brick; stars or a list of SpatRasters.
 #' @param directions The number of directions in which patches should be
 #' connected: 4 (rook's case) or 8 (queen's case).
 #'
@@ -34,22 +34,22 @@
 #' @return tibble
 #'
 #' @examples
+#' landscape <- terra::rast(landscapemetrics::landscape)
 #' lsm_l_para_mn(landscape)
 #'
 #' @aliases lsm_l_para_mn
 #' @rdname lsm_l_para_mn
 #'
 #' @references
-#' McGarigal, K., SA Cushman, and E Ene. 2012. FRAGSTATS v4: Spatial Pattern Analysis
-#' Program for Categorical and Continuous Maps. Computer software program produced by
-#' the authors at the University of Massachusetts, Amherst. Available at the following
-#' web site: https://www.umass.edu/landeco/
+#' McGarigal K., SA Cushman, and E Ene. 2023. FRAGSTATS v4: Spatial Pattern Analysis
+#' Program for Categorical Maps. Computer software program produced by the authors;
+#' available at the following web site: https://www.fragstats.org
 #'
 #' @export
 lsm_l_para_mn <- function(landscape, directions = 8) {
     landscape <- landscape_as_list(landscape)
 
-    result <- lapply(X = raster::as.list(landscape),
+    result <- lapply(X = terra::as.list(landscape),
                      FUN = lsm_l_para_mn_calc,
                      directions = directions)
 
