@@ -2,7 +2,7 @@
 #'
 #' @description Shannons's evenness index (Diversity metric)
 #'
-#' @param landscape Raster* Layer, Stack, Brick, SpatRaster (terra), stars, or a list of rasterLayers.
+#' @param landscape A categorical raster object: SpatRaster; Raster* Layer, Stack, Brick; stars or a list of SpatRasters.
 #'
 #' @details
 #' \deqn{SHEI = \frac{- \sum \limits_{i = 1} ^ {m} (P_{i} * \ln P_{i})} {\ln m}}
@@ -25,16 +25,16 @@
 #' @return tibble
 #'
 #' @examples
+#' landscape <- terra::rast(landscapemetrics::landscape)
 #' lsm_l_shei(landscape)
 #'
 #' @aliases lsm_l_shei
 #' @rdname lsm_l_shei
 #'
 #' @references
-#' McGarigal, K., SA Cushman, and E Ene. 2012. FRAGSTATS v4: Spatial Pattern Analysis
-#' Program for Categorical and Continuous Maps. Computer software program produced by
-#' the authors at the University of Massachusetts, Amherst. Available at the following
-#' web site: https://www.umass.edu/landeco/
+#' McGarigal K., SA Cushman, and E Ene. 2023. FRAGSTATS v4: Spatial Pattern Analysis
+#' Program for Categorical Maps. Computer software program produced by the authors;
+#' available at the following web site: https://www.fragstats.org
 #'
 #' Shannon, C., and W. Weaver. 1949. The mathematical theory of
 #' communication. Univ. IllinoisPress, Urbana
@@ -72,11 +72,10 @@ lsm_l_shei_calc <- function(landscape, resolution = NULL){
 
     prop <- prop$value / 100
 
-    log_len_prop <- log(length(prop), exp(1))
-    if (log_len_prop == 0){
+    if (length(prop) == 1){
         shei <- 0
     } else {
-        shei <- sum(-prop * log_len_prop) / log_len_prop
+        shei <- -sum(prop * log(prop)) / log(length(prop))
     }
 
     return(tibble::tibble(level = "landscape",
