@@ -2,7 +2,7 @@
 #'
 #' @description Contiguity index (Shape metric)
 #'
-#' @param landscape Raster* Layer, Stack, Brick, SpatRaster (terra), stars, or a list of rasterLayers.
+#' @param landscape A categorical raster object: SpatRaster; Raster* Layer, Stack, Brick; stars or a list of SpatRasters.
 #' @param directions The number of directions in which patches should be
 #' connected: 4 (rook's case) or 8 (queen's case).
 #'
@@ -42,16 +42,16 @@
 #' @return tibble
 #'
 #' @examples
+#' landscape <- terra::rast(landscapemetrics::landscape)
 #' lsm_p_contig(landscape)
 #'
 #' @aliases lsm_p_contig
 #' @rdname lsm_p_contig
 #'
 #' @references
-#' McGarigal, K., SA Cushman, and E Ene. 2012. FRAGSTATS v4: Spatial Pattern Analysis
-#' Program for Categorical and Continuous Maps. Computer software program produced by
-#' the authors at the University of Massachusetts, Amherst. Available at the following
-#' web site: https://www.umass.edu/landeco/
+#' McGarigal K., SA Cushman, and E Ene. 2023. FRAGSTATS v4: Spatial Pattern Analysis
+#' Program for Categorical Maps. Computer software program produced by the authors;
+#' available at the following web site: https://www.fragstats.org
 #'
 #' LaGro, J. 1991. Assessing patch shape in landscape mosaics.
 #' Photogrammetric Engineering and Remote Sensing, 57(3), 285-293
@@ -76,7 +76,7 @@ lsm_p_contig_calc <- function(landscape, directions) {
 
     # convert to matrix
     if (!inherits(x = landscape, what = "matrix")) {
-        landscape <- raster::as.matrix(landscape)
+        landscape <- terra::as.matrix(landscape, wide = TRUE)
     }
 
     # all values NA
@@ -125,9 +125,7 @@ lsm_p_contig_calc <- function(landscape, directions) {
                                                                 directions = as.matrix(straigth_matrix)) * 2
 
         # calculated contiguity
-        contiguity <- (((diagonal_neighbours +
-                             straigth_neighbours +
-                             n_cells) /
+        contiguity <- (((diagonal_neighbours + straigth_neighbours + n_cells) /
                             n_cells) - 1) / 12
 
         class <- patches_class
