@@ -2,7 +2,7 @@
 #'
 #' @description Moving window
 #'
-#' @param landscape Raster* Layer, Stack, Brick, SpatRaster (terra), stars, or a list of rasterLayers.
+#' @param landscape A categorical raster object: SpatRaster; Raster* Layer, Stack, Brick; stars or a list of SpatRasters.
 #' @param window Moving window matrix.
 #' @param level Level of metrics. Either 'patch', 'class' or 'landscape' (or vector with combination).
 #' @param metric Abbreviation of metrics (e.g. 'area').
@@ -16,9 +16,9 @@
 #' @details
 #' The function calculates for each focal cell the selected landscape metrics (currently only landscape level
 #' metrics are allowed) for a local neighbourhood. The neighbourhood can be specified using a matrix. For more
-#' details, see \code{?raster::focal()}. The result will be a \code{RasterLayer} in which each focal cell includes
+#' details, see \code{?terra::focal()}. The result will be a \code{RasterLayer} in which each focal cell includes
 #' the value of its neighbourhood and thereby allows to show gradients and variability in the landscape (Hagen-Zanker 2016).
-#' To be type stable, the acutally result is always a nested list (first level for \code{RasterStack} layers, second level
+#' To be type stable, the actual result is always a nested list (first level for \code{RasterStack} layers, second level
 #' for selected landscape metrics).
 #'
 #' @seealso
@@ -30,6 +30,8 @@
 #'
 #' @examples
 #' \dontrun{
+#' landscape <- terra::rast(landscapemetrics::landscape)
+#' landscape_stack <- c(landscape, landscape)
 #' window <- matrix(1, nrow = 5,ncol = 5)
 #' window_lsm(landscape, window = window, what = c("lsm_l_pr", "lsm_l_joinent"))
 #' window_lsm(landscape_stack, window = window, what = c("lsm_l_pr", "lsm_l_joinent"))
@@ -49,10 +51,9 @@
 #' and its application to landscape pattern analysis. International journal of applied
 #' earth observation and geoinformation, 44, 205-216.
 #'
-#' McGarigal, K., Cushman, S.A., and Ene E. 2012. FRAGSTATS v4: Spatial Pattern Analysis
-#' Program for Categorical and Continuous Maps. Computer software program produced by
-#' the authors at the University of Massachusetts, Amherst. Available at the following
-#' website: <https://www.umass.edu/landeco/>
+#' McGarigal K., SA Cushman, and E Ene. 2023. FRAGSTATS v4: Spatial Pattern Analysis
+#' Program for Categorical Maps. Computer software program produced by the authors;
+#' available at the following web site: https://www.fragstats.org
 #'
 #' @export
 window_lsm <- function(landscape,
@@ -130,7 +131,7 @@ window_lsm_int <- function(landscape,
     points <- raster_to_points(landscape)[, 2:4]
 
     # resolution of original raster
-    resolution <- raster::res(landscape)
+    resolution <- terra::res(landscape)
 
     # create object for warning messages
     warning_messages <- character(0)
@@ -143,15 +144,14 @@ window_lsm_int <- function(landscape,
             cat("\r> Progress metrics: ", current_metric, "/", number_metrics)
         }
 
-        raster::focal(x = landscape, w = window, fun = function(x) {
+        terra::focal(x = landscape, w = dim(window), fun = function(x) {
 
             calculate_lsm_focal(landscape = x,
                                 raster_window = window,
                                 resolution = resolution,
                                 points = points,
                                 what = metrics_list[[current_metric]],
-                                ...)},
-            pad = TRUE, padValue = NA)
+                                ...)}, fillvalue = NA)
         })},
         warning = function(cond) {
 
