@@ -1,12 +1,9 @@
-context("class level lsm_c_area_mn metric")
-
 landscapemetrics_class_landscape_value <- lsm_c_area_mn(landscape)
 
 test_that("lsm_c_area_mn is typestable", {
-    expect_is(lsm_c_area_mn(landscape), "tbl_df")
-    expect_is(lsm_c_area_mn(landscape_stack), "tbl_df")
-    expect_is(lsm_c_area_mn(landscape_brick), "tbl_df")
-    expect_is(lsm_c_area_mn(landscape_list), "tbl_df")
+    expect_s3_class(lsm_c_area_mn(landscape), "tbl_df")
+    expect_s3_class(lsm_c_area_mn(landscape_stack), "tbl_df")
+    expect_s3_class(lsm_c_area_mn(landscape_list), "tbl_df")
 })
 
 test_that("lsm_c_area_mn returns the desired number of columns", {
@@ -21,5 +18,3 @@ test_that("lsm_c_area_mn returns in every column the correct type", {
     expect_type(landscapemetrics_class_landscape_value$metric, "character")
     expect_type(landscapemetrics_class_landscape_value$value, "double")
 })
-
-
