@@ -1,7 +1,6 @@
-context("entropy")
-
 buys <- c("no", "no", "yes", "yes", "yes", "no", "yes",
          "no", "yes", "yes", "yes", "yes", "yes", "no")
+
 freqs <- table(buys) / length(buys)
 
 e_true1 <- -sum(freqs * log2(freqs))
@@ -13,11 +12,11 @@ e_result2 <- rcpp_get_entropy(freqs, "log")
 e_result3 <- rcpp_get_entropy(freqs, "log10")
 
 test_that("rcpp_get_entropy results are correct", {
-    expect_equivalent(e_result1, e_true1)
-    expect_equivalent(e_result2, e_true2)
-    expect_equivalent(e_result3, e_true3)
+    expect_equal(e_result1, e_true1)
+    expect_equal(e_result2, e_true2)
+    expect_equal(e_result3, e_true3)
 })
 
 test_that("rcpp_get_entropy is typestable", {
-    expect_is(e_result1, "numeric")
+    expect_type(e_result1, "double")
 })
